package com.gic.haoban.manage.web.controller;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.druid.util.StringUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.gic.api.base.commons.Page;
import com.gic.commons.util.DateUtil;
import com.gic.enterprise.api.dto.EnterpriseAndUserDTO;
import com.gic.enterprise.api.dto.EnterpriseDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StoreSearchDTO;
import com.gic.enterprise.api.service.EnterpriseService;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.EnterpriseDetailDTO;
import com.gic.haoban.manage.api.dto.SecretSettingDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.enums.SecretTypeEnum;
import com.gic.haoban.manage.api.service.DealSyncOperationApiService;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.anno.IgnoreLogin;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.config.Config;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.EnterpriseSearchVO;
import com.gic.haoban.manage.web.vo.LoginVO;
import com.gic.haoban.manage.web.vo.SecretSettingVO;
import com.gic.haoban.manage.web.vo.StoreVo;
import com.gic.quartz.api.dto.QuartzTaskDTO;
import com.gic.quartz.api.service.QuartzService;
import com.gic.redis.data.util.RedisUtil;
import com.gic.wechat.api.dto.qywx.UserDTO;
import com.gic.wechat.api.service.qywx.QywxUserApiService;
import com.gic.wechat.token.api.dto.QywxCorpInfoDTO;
import com.gic.wechat.token.api.service.QywxTokenManageService;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;
import java.util.stream.Collectors;

@RestController
public class WxEnterpriseController extends WebBaseController{
	private static Logger logger  = LoggerFactory.getLogger(WxEnterpriseController.class);
	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	@Autowired
	private EnterpriseService enterpriseService;
	@Autowired
	private WxEnterpriseApiService wxEnterpriseApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StoreService storeService;
	@Autowired
	private QywxTokenManageService qywxTokenManageService;
	@Autowired
	private Config config;
	@Autowired
	private QywxUserApiService qywxUserApiService;

	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private DealSyncOperationApiService dealSyncOperationApiService;
	@Autowired
	private QuartzService quartzService;
	
	
	//授权企业列表
	@IgnoreLogin
	@RequestMapping("wx-enterprise-list")
	public HaobanResponse wxEnterpriseList() {
//		String wxEnterpriseId = "123456";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		List<EnterpriseDetailDTO> list = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		if(CollectionUtil.isNotEmpty(list)){
			List<String> enterpriseIds = list.stream().map(s->s.getEnterpriseId()).collect(Collectors.toList());
			List<EnterpriseDTO> enterpriseList = enterpriseService.listEnterpriseByIds(enterpriseIds);
			Map<String,EnterpriseDTO> map = com.gic.commons.util.CollectionUtil.toMap(enterpriseList, "enterpriseId");
			for(EnterpriseDetailDTO dto:list){
				EnterpriseDTO enterpriseDTO = map.get(dto.getEnterpriseId());
				if(enterpriseDTO!=null){
					dto.setEnterpriseName(enterpriseDTO.getEnterpriseName());
					dto.setEnterpriseLogo(enterpriseDTO.getQcloudImageUrl());
					dto.setBrandName(enterpriseDTO.getBrandName());
				}
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1, list);
 
	}
	
	//企业信息
	@IgnoreLogin
	@RequestMapping("wxEnterprise-detail")
	public HaobanResponse enterpriseDetail(String wxEnterpriseId) {
		if(StringUtils.isEmpty(wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		WxEnterpriseDTO wxEnterpriseDTO = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterpriseDTO == null){
			return resultResponse(HaoBanErrCode.ERR_100018);
		}
		wxEnterpriseDTO.setSmallVersion("免费版");
		wxEnterpriseDTO.setStoreTotal(departmentApiService.totalStoreCountByEnterpriseId(wxEnterpriseId));
		return resultResponse(HaoBanErrCode.ERR_1,wxEnterpriseDTO);
	}
	
	//企业信息
	@IgnoreLogin
	@RequestMapping("wxEnterprise-refresh")
	public HaobanResponse enterpriseRefresh(String wxEnterpriseId) {
		if(StringUtils.isEmpty(wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		WxEnterpriseDTO wxEnterpriseDTO = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterpriseDTO == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		QywxCorpInfoDTO dto = qywxTokenManageService.getCorpInfo(wxEnterpriseDTO.getCorpid(), config.getWxSuiteid());
		Long verifiedEndTime = dto.getVerifiedEndTime();
		if(dto == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		logger.info("【企业同步】dto={}",JSON.toJSONString(dto));
		WxEnterpriseDTO wxDTO = EntityUtil.changeEntityByJSON(WxEnterpriseDTO.class, dto);
		if(verifiedEndTime != null){
			wxDTO.setVerifiedEndTime(new Date(verifiedEndTime * 1000));
		}
		wxDTO.setWxEnterpriseId(wxEnterpriseId);
		wxEnterpriseApiService.update(wxDTO);
		return resultResponse(HaoBanErrCode.ERR_1,wxEnterpriseDTO);
	}
	//gic企业列表
	@IgnoreLogin
	@RequestMapping("enterprise-search")
	public HaobanResponse gicEnterpriseDetail(String enterpriseName) {
		if(StringUtils.isEmpty(enterpriseName)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		EnterpriseAndUserDTO dto = enterpriseService.getEnterpriseAndUserByName(enterpriseName);
		EnterpriseSearchVO vo = EntityUtil.changeEntityByJSON(EnterpriseSearchVO.class, dto);
		if(vo != null){
			String enterpriseId = vo.getEnterpriseId();
			EnterpriseDTO enterprise = enterpriseService.getEnterpriseByEid(enterpriseId);
			if(enterprise != null){
				vo.setBrandName(enterprise.getBrandName());
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,vo);
 
	}
	//微信企业绑定接口
	@IgnoreLogin
	@RequestMapping("wx-enterprise-bind")
	public HaobanResponse wxEnterpriseBind(String enterpriseId,String wxEnterpriseId,String version) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(enterpriseId,version)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		StaffDTO staff = login.getStaffDTO();
		String staffId = staff.getStaffId();
		String staffName = staff.getStaffName();
		int i = wxEnterpriseRelatedApiService.wxEnterpriseBind(enterpriseId,wxEnterpriseId,version,staffId,staffName);
		if(i==1){
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
 
	}
	//溢出门店列表
	@IgnoreLogin
	@RequestMapping("store-full-list")
	public HaobanResponse storeFullList(BasePageInfo basePageInfo,String keyWord) {
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
//		String wxEnterpriseId = "1";
		int maxVersionCount = 0;
		List<EnterpriseDetailDTO>  enterpriseList = wxEnterpriseRelatedApiService.listEnterpriseByWxEnterpriseId(wxEnterpriseId);
		if(CollectionUtil.isEmpty(enterpriseList)){
			return resultResponse(HaoBanErrCode.ERR_10010);
		}
		List<String> enterpriseIds = enterpriseList.stream().map(s->s.getEnterpriseId()).collect(Collectors.toList());
		//获取门店列表
		Page page1 = new Page<>();
		page1.setCurrentPage(1);
		page1.setPageSize(Integer.MAX_VALUE);
		StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
		storeSearchDTO.setEnterpriseIdList(enterpriseIds);
		storeSearchDTO.setSearchName(keyWord);
		Page storePage = storeService.storeListPage(page1, storeSearchDTO);
		if(storePage == null || storePage.getResult()==null){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		List<StoreDTO> t_list = storePage.getResult();
		List<String> storeIds = t_list.stream().map(s->s.getStoreId()).collect(Collectors.toList());
		if(StringUtils.isEmpty(keyWord)){
			storeIds = null;
		}
		Page<DepartmentDTO> page = departmentApiService.pageFullStoreByWxEnterpriseId(wxEnterpriseId, keyWord,storeIds,maxVersionCount, basePageInfo);
		List<DepartmentDTO> list = page.getResult();
		List<StoreVo> resultList = EntityUtil.changeEntityListByJSON(StoreVo.class,list);
		
		
		
		List<String> t_storeIds = list.stream().map(s->s.getRelatedId()).collect(Collectors.toList());
		String [] storeIdArr =  t_storeIds.toArray(new String[t_storeIds.size()]);
		List<StoreDTO> storeList = storeService.getStores(storeIdArr);
		Map<String,StoreDTO> map = com.gic.commons.util.CollectionUtil.toMap(storeList, "storeId");
		
		for(StoreVo vo:resultList){
			if(map.get(vo.getRelatedId())!=null){
				vo.setStoreCode(map.get(vo.getRelatedId()).getStoreCode());
				vo.setStoreId(map.get(vo.getRelatedId()).getStoreId());
				vo.setStoreName(map.get(vo.getRelatedId()).getStoreName());
			}
		}
		
		
		Page resultPage = new Page<>(); 
		resultPage.setCurrentPage(page.getCurrentPage());
		resultPage.setPageSize(page.getPageSize());
		resultPage.setTotalCount(page.getTotalCount());
		resultPage.setResult(resultList);
		return resultResponse(HaoBanErrCode.ERR_1,resultPage);
		
	}
	
	//微信企业是否设置key
	@IgnoreLogin
	@RequestMapping("is-wx-enterprise-secret-set")
	public HaobanResponse isWxEnterpriseSecretSet() {
		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		List<SecretSettingDTO> listSecret = wxEnterpriseApiService.listSecret(wxEnterpriseId);
		if (CollectionUtils.isEmpty(listSecret)) {
			return resultResponse(HaoBanErrCode.ERR_1,false);
		}
		Set<Integer> secretTypeList = listSecret.stream().filter(secretSettingDTO -> {
			return secretSettingDTO.getCheckFlag() == 1;
		}).map(secretSettingDTO -> {
			return secretSettingDTO.getSecretType();
		}).collect(Collectors.toSet());

		if (CollectionUtils.isEmpty(secretTypeList)) {
			return resultResponse(HaoBanErrCode.ERR_1,false);
		}
		if (secretTypeList.contains(SecretTypeEnum.HAOBAN_HELP.getVal())&&secretTypeList.contains(SecretTypeEnum.CONTACT_CUSTOMER.getVal())) {
			return resultResponse(HaoBanErrCode.ERR_1,true);
		}else{
			return resultResponse(HaoBanErrCode.ERR_1,false);
		}
//		if(wxEnterprise != null && org.apache.commons.lang3.StringUtils.isAnyBlank(wxEnterprise.getContactSecret(),wxEnterprise.getWxSecretKey())){
//			return resultResponse(HaoBanErrCode.ERR_1,false);
//		}
//		return resultResponse(HaoBanErrCode.ERR_1,true);
 
	}
	
	//微信企业绑定接口绑定通讯录key
	@IgnoreLogin
	@RequestMapping("wx-enterprise-contact-secret-set")
	public HaobanResponse wxEnterpriseSecretSet(String contactSecret) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(contactSecret)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterprise == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		contactSecret = contactSecret.trim();
		UserDTO user = qywxUserApiService.getSelfWorkWxUser(wxEnterprise.getCorpid(), contactSecret, getWxUserId(wxEnterpriseId,login.getStaffDTO()));
		logger.info("【保存联系人key】user={}",JSON.toJSONString(user));
		SecretSettingDTO secretSetting = wxEnterpriseApiService.getSecretSetting(wxEnterpriseId, SecretTypeEnum.CONTACT_SECRET.getVal(), null);
		if (null== secretSetting) {
			secretSetting=new SecretSettingDTO();
		}
		secretSetting.setSecretType(SecretTypeEnum.CONTACT_SECRET.getVal());
		secretSetting.setSecretName(SecretTypeEnum.CONTACT_SECRET.getName());
		secretSetting.setWxEnterpriseId(wxEnterpriseId);
		secretSetting.setEnterpriseId("-1");
		if(user != null){
			secretSetting.setSecretVal(contactSecret);
			secretSetting.setCheckFlag(1);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_1,true);
		}else{
			secretSetting.setCheckFlag(0);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_10013);
		}
 
	}
	
	//微信企业绑定接口绑定通讯录key
	@IgnoreLogin
	@RequestMapping("wx-enterprise-wx-secret-set")
	public HaobanResponse wxEnterpriseWxSecretSet(String wxSecretKey) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(wxSecretKey)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterprise == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		wxSecretKey = wxSecretKey.trim();
		String res = qywxUserApiService.listSelfExternalUserid(wxEnterprise.getCorpid(), wxSecretKey, getWxUserId(wxEnterpriseId,login.getStaffDTO()));
		logger.info("【保存联系人key】res={}",res);

		SecretSettingDTO secretSetting = wxEnterpriseApiService.getSecretSetting(wxEnterpriseId, SecretTypeEnum.CONTACT_CUSTOMER.getVal(), null);
		if (null== secretSetting) {
			secretSetting=new SecretSettingDTO();
		}
		secretSetting.setSecretType(SecretTypeEnum.CONTACT_CUSTOMER.getVal());
		secretSetting.setSecretName(SecretTypeEnum.CONTACT_CUSTOMER.getName());
		secretSetting.setWxEnterpriseId(wxEnterpriseId);
		secretSetting.setEnterpriseId("-1");
		if(res != null){
			secretSetting.setSecretVal(wxSecretKey);
			secretSetting.setCheckFlag(1);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_1,true);
		}else{
			secretSetting.setCheckFlag(0);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_10013);
		}
//
//		if(res == null){
//			wxEnterprise.setWxSecretKeyLastTime(new Date());
//			wxEnterpriseApiService.update(wxEnterprise);
//			return resultResponse(HaoBanErrCode.ERR_10013);
//		}else{
//			wxEnterprise.setWxSecretKey(wxSecretKey);
//			wxEnterprise.setWxSecretKeyLastTime(new Date());
//			wxEnterpriseApiService.update(wxEnterprise);
//			return resultResponse(HaoBanErrCode.ERR_1,true);
//		}
 
	}
	
	//微信企业会员小程序
	@IgnoreLogin
	@RequestMapping("wx-enterprise-member-secret-set")
	public HaobanResponse wxEnterpriseMemberSecretSet(String memberSecret,String enterpriseId,String secretName) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(memberSecret)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterprise == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		memberSecret = memberSecret.trim();

		SecretSettingDTO secretSetting = wxEnterpriseApiService.getSecretSetting(wxEnterpriseId, SecretTypeEnum.MEMBER_WAPP.getVal(), enterpriseId);
		if (null== secretSetting) {
			secretSetting=new SecretSettingDTO();
		}else{
			if(memberSecret.equals(secretSetting.getSecretVal())){
				logger.info("secret已经保存过");
				return resultResponse(HaoBanErrCode.ERR_100017);
			}
		}
		UserDTO user = qywxUserApiService.getSelfWorkWxUser(wxEnterprise.getCorpid(), memberSecret, getWxUserId(wxEnterpriseId,login.getStaffDTO()));
		secretSetting.setSecretType(SecretTypeEnum.MEMBER_WAPP.getVal());
		secretSetting.setSecretName(secretName);
		secretSetting.setEnterpriseId(enterpriseId);
		secretSetting.setWxEnterpriseId(wxEnterpriseId);

		if(user != null){
			secretSetting.setSecretVal(memberSecret);
			secretSetting.setCheckFlag(1);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_1,true);
		}else{
			secretSetting.setCheckFlag(0);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_10013);
		}
	}

	private String getWxUserId(String wxEnterpriseId,StaffDTO loginStaffDTO) {
		if (loginStaffDTO!=null && (!StringUtils.isEmpty(loginStaffDTO.getWxUserId()))) {
			return loginStaffDTO.getWxUserId();
		}
		StaffDTO staffOne = staffApiService.getWxStaffOne(wxEnterpriseId);
		return staffOne.getWxUserId();
	}

	//微信企业绑定接口绑定通讯录key
	@IgnoreLogin
	@RequestMapping("wx-enterprise-haoban-secret-set")
	public HaobanResponse wxEnterpriseHaobanSecretSet(String contactSecret,String memberSecret) {
		if (!StringUtils.isEmpty(memberSecret)) {
			contactSecret=memberSecret;
		}
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(contactSecret)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterprise == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}
		contactSecret = contactSecret.trim();

		UserDTO user = qywxUserApiService.getSelfWorkWxUser(wxEnterprise.getCorpid(), contactSecret, getWxUserId(wxEnterpriseId,login.getStaffDTO()));
		logger.info("【保存联系人key】user={}",JSON.toJSONString(user));
		SecretSettingDTO secretSetting = wxEnterpriseApiService.getSecretSetting(wxEnterpriseId, SecretTypeEnum.HAOBAN_HELP.getVal(), null);
		if (null== secretSetting) {
			secretSetting=new SecretSettingDTO();
		}
		secretSetting.setSecretType(SecretTypeEnum.HAOBAN_HELP.getVal());
		secretSetting.setSecretName(SecretTypeEnum.HAOBAN_HELP.getName());
		secretSetting.setWxEnterpriseId(wxEnterpriseId);
		secretSetting.setEnterpriseId("-1");
		if(user != null){
			secretSetting.setSecretVal(contactSecret);
			secretSetting.setCheckFlag(1);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_1,true);
		}else{
			secretSetting.setCheckFlag(0);
			wxEnterpriseApiService.saveSecretSetting(secretSetting);
			return resultResponse(HaoBanErrCode.ERR_10013);
		}

	}


	//微信企业会员小程序
	@IgnoreLogin
	@RequestMapping("secret-list")
	public HaobanResponse secretList() {

		String wxEnterpriseId = "";
		LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		wxEnterpriseId = login.getWxEnterpriseId();
		WxEnterpriseDTO wxEnterprise = wxEnterpriseApiService.getOne(wxEnterpriseId);
		if(wxEnterprise == null){
			return resultResponse(HaoBanErrCode.ERR_10012);
		}

		List<SecretSettingDTO> listSecret = wxEnterpriseApiService.listSecret(wxEnterpriseId);
		List<SecretSettingVO> listRet=EntityUtil.changeEntityListByJSON(SecretSettingVO.class,listSecret);
		if (CollectionUtils.isNotEmpty(listRet)) {
			listRet.forEach(secretSettingVO -> {
				if ((!StringUtils.isEmpty(secretSettingVO.getEnterpriseId()))&&(!secretSettingVO.getEnterpriseId().equals("-1"))) {
					EnterpriseDTO enterpriseDTO = enterpriseService.getEnterpriseById(secretSettingVO.getEnterpriseId());
					secretSettingVO.setEnterpriseName(enterpriseDTO == null?"":enterpriseDTO.getBrandName());
				}
			});
		}
		return resultResponse(HaoBanErrCode.ERR_1,listRet);
	}


	//微信企业会员小程序
	@IgnoreLogin
	@RequestMapping("member-secret-del")
	public HaobanResponse delMemberSecret(String secretId) {
		if(org.apache.commons.lang3.StringUtils.isAnyBlank(secretId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}


		boolean b = wxEnterpriseApiService.delSecretSetting(secretId);
		return resultResponse(HaoBanErrCode.ERR_1,b);

	}
	
	//企业信息
	@RequestMapping("enterprise-is-over")
	public HaobanResponse enterpriseIsOver(String enterpriseId) {
		if(StringUtils.isEmpty(enterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		EnterpriseDTO enterprise = enterpriseService.getEnterpriseByEid(enterpriseId);
		if(enterprise == null || enterprise.getExpireTime() == null){
			return resultResponse(HaoBanErrCode.ERR_1,false);
		}
		if(enterprise.getExpireTime().getTime() > System.currentTimeMillis()){
			return resultResponse(HaoBanErrCode.ERR_1,false);
		}
		return resultResponse(HaoBanErrCode.ERR_1,true);
	}
	
	/**
     * 刷新企业微信好友
     * @return
     */
    @RequestMapping("/fresh-wx-friend")
    public HaobanResponse freshWxFriend(){
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		String dayKey = "haoban_fresh-wx-friend-day" + wxEnterpriseId + DateUtil.dateToStr(new Date(), "yyyy-MM-dd");
		String monthKey = "haoban_fresh-wx-friend-month" + wxEnterpriseId + DateUtil.dateToStr(new Date(), "yyyy-MM");
		String dateKey = "haoban_fresh-wx-friend-date" + wxEnterpriseId;
		Integer dayCount = RedisUtil.getCache(dayKey) == null?0:Integer.parseInt(RedisUtil.getCache(dayKey).toString());
		Integer monthCount = RedisUtil.getCache(monthKey) == null?0:Integer.parseInt(RedisUtil.getCache(monthKey).toString());
		if(dayCount >= 1){
			return resultResponse(HaoBanErrCode.ERR_100019);
		}
		if(monthCount >= 3){
			return resultResponse(HaoBanErrCode.ERR_100020);
		}
		String taskId = dealSyncOperationApiService.createWxFriendTask(wxEnterpriseId, "刷新企微好友", login.getStaffDTO().getStaffId(), "刷新企微好友");
		if(StringUtils.isEmpty(taskId)){
			return resultResponse(HaoBanErrCode.ERR_100021);
		}
//		dealSyncOperationApiService.dealWxFriendClerk(taskId, wxEnterpriseId);
		RedisUtil.setCache(dayKey, dayCount+1);
		RedisUtil.setCache(monthKey, monthCount+1);
		RedisUtil.setCache(dateKey, DateUtil.dateToStr(new Date(),DateUtil.FORMAT_DATETIME_19));
    	return resultResponse(HaoBanErrCode.ERR_1);
    }
    
    private QuartzTaskDTO buildQuartzTaskDTO(String id) {
  	  QuartzTaskDTO taskDTO = new QuartzTaskDTO();
        taskDTO.setReferId(id);
        taskDTO.setTaskMethod("quartWxFriendClerk");
        taskDTO.setTaskService("com.gic.haoban.manage.api.service.DealSyncOperationApiService");
        return taskDTO;
	}
	
    
    /**
     * 获取企业微信好友刷新时间
     * @return
     */
    @RequestMapping("/get-fresh-detail")
    public HaobanResponse getFreshDetail(){
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		String dateKey = "haoban_fresh-wx-friend-date" + wxEnterpriseId;
    	RedisUtil.getCache(dateKey);
    	return resultResponse(HaoBanErrCode.ERR_1,RedisUtil.getCache(dateKey));
    }
	
    /**
     * 获取刷新好友开关接口
     * @return
     */
    @RequestMapping("/get-fresh-on-off")
    public HaobanResponse getFreshOnOff(){
    	LoginVO login = (LoginVO) AuthRequestUtil.getLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		String dateKey = "haoban_fresh-wx-friend-enterprise";
		Object value = RedisUtil.getCache(dateKey);
		if(value != null){
			String valueStr = value.toString();
			return resultResponse(HaoBanErrCode.ERR_1,valueStr.contains(wxEnterpriseId));
		}
    	return resultResponse(HaoBanErrCode.ERR_1,false);
    }

}
